@@ -42,7 +42,7 @@ class Acco:
         """
         return {
             'giataid': self.giataid,
-            'source': self.giataid,
+            'source': self.source,
             'images': [{'url': image.url, 'descriptions': image.descriptions} for image in self.images]
         }
 
